---
name: "🐞Bug报告"
about: "报告钻石铲未按预期运行的问题"
labels: type:bug
---

# Bug 报告

* [ ] 我已经搜索过所有打开或已经关闭的issue，确认没有类似的问题
* [ ] 我正在提交一份关于现有功能未按预期运行的报告

## 基本信息
- **类型**: Bug报告

## 问题描述
<!-- 请用简洁的语言说明核心问题 -->

## 复现指引
### 步骤说明
<!-- 请提供复现问题的步骤 -->

### 环境信息
<!-- 请提供相关环境信息 -->

## 诊断信息(Optional)
<!-- 附加有助于排查的内容 -->

## 解决方案建议(Optional)
<!-- 如果你有解决方案的建议，请在这里描述 -->
---
Current template created on 2025-04-10 by stupidfish.